@@ -4,6 +4,8 @@ from tuxbake.models import OEBuild
 
 @patch.multiple(
     OEBuild,
+    prepare=MagicMock(),
+    do_cleanup=MagicMock(),
     do_build=MagicMock(return_value="build_called"),
     publish_artifacts=MagicMock(return_value="publish_artifacts_called"),
 )
