@@ -3,10 +3,14 @@
 
 import argparse
 import os
+from pathlib import Path
+import sys
 from typing import List
 from urllib.parse import urlparse
+import yaml
 
-from tuxbake.utils import download_file
+from tuxbake import __version__
+from tuxbake.utils import download_file, is_json
 from tuxmake.runtime import Runtime
 
 
@@ -15,10 +19,28 @@ class supported:
 
 
 def file_or_url(value):
-    if os.path.exists(value):
+    if Path(value).is_file():
+        if is_json(Path(value).read_text()):
+            raise argparse.ArgumentTypeError(
+                "The build definition file is not valid. It must be in YAML format"
+            )
         return value
     elif urlparse(value).scheme in ["http", "https"]:
-        return download_file(value, os.path.abspath("build-definition.json"))
+        build_definition = os.path.abspath("build-definition.yaml")
+        resp = download_file(value)
+        if is_json(resp):
+            raise argparse.ArgumentTypeError(
+                "The build definition file is not valid. It must be in YAML format"
+            )
+        try:
+            # Dump into yaml
+            with open(build_definition, "w+") as f:
+                yaml.safe_dump(yaml.safe_load(resp), f, indent=4, sort_keys=True)
+        except yaml.YAMLError as e:
+            print(f"E: Invalid build definition file\n{e}", file=sys.stderr)
+            sys.exit(1)
+
+        return build_definition
 
     raise argparse.ArgumentTypeError(f"'{value}' is not a valid file path or URL")
 
@@ -28,13 +50,13 @@ def file_or_url(value):
 ##########
 def setup_parser() -> argparse.ArgumentParser:
     parser = argparse.ArgumentParser(prog="tuxbake", description="TuxBake")
-    #    parser.add_argument(
-    #    "--version", action="version", version=f"%(prog)s, {__version__}"
-    # )
+    parser.add_argument(
+        "--version", action="version", version=f"%(prog)s, {__version__}"
+    )
     group = parser.add_argument_group("OE Build Parameters")
     group.add_argument(
         "--build-definition",
-        help="Path/URL to build definition json file",
+        help="Path/URL to build definition yaml file",
         required=True,
         type=file_or_url,
     )
