@@ -104,10 +104,12 @@ def validate_git_dest(dest):
 
 def validate_container(container):
     supported_containers = [
+        "ubuntu-24.04",
         "ubuntu-22.04",
         "ubuntu-20.04",
         "ubuntu-18.04",
         "ubuntu-16.04",
+        "centos-7",
         "centos-8",
         "debian-bookworm",
         "debian-bullseye",
