@@ -172,7 +172,7 @@ def copy_artifacts(artifacts_path_list, dest_dir):
         cmd = f"mkdir -p {dest_dir}".split()
         run_cmd(cmd, None)
     cmd = f"cp -R {dirs} {dest_dir}".split()
-    run_cmd(cmd, None, fail_ok=True)
+    run_cmd(cmd, None, fail_ok=False)
 
 
 def run_cmd(cmd, src_dir, env=None, fail_ok=False):
@@ -184,7 +184,7 @@ def run_cmd(cmd, src_dir, env=None, fail_ok=False):
     process.out, process.err = process.communicate()
     handle_log([msg, process.out, process.err])
     if not fail_ok and process.returncode != 0:
-        raise TuxbakeRunCmdError(f"Failed to run: {' '.join(cmd)}")
+        raise TuxbakeRunCmdError(f"Failed to run: {' '.join(cmd)}: {process.err}")
     return process
 
 
@@ -206,17 +206,22 @@ def handle_log(logs_list):
     return
 
 
-def download_file(url, file_dest):
+def is_json(json_str):
+    try:
+        json.loads(json_str)
+        return True
+    except (json.JSONDecodeError, TypeError):
+        return False
+
+
+def download_file(url, dest=None):
     try:
         response = requests.get(url)
         response.raise_for_status()
-        json_data = response.json()
-        with open(file_dest, "w") as build_definition:
-            json.dump(json_data, build_definition, indent=4)
-        return file_dest
-    except requests.exceptions.JSONDecodeError as e:
-        print(f"Invalid json file: {e}")
-        sys.exit(1)
+        if dest:
+            with open(dest, "w") as f:
+                f.write(response.text)
+        return response.text
     except requests.exceptions.RequestException as e:
-        print(f"Failed to download build definition file: {e}")
+        print(f"E: Failed to download build definition file\n{e}", file=sys.stderr)
         sys.exit(1)
